
# Slot: defining_slots


The combination of is a plus defining slots form a genus-differentia definition, or the set of necessary and sufficient conditions that can be transformed into an OWL equivalence axiom

URI: [linkml:defining_slots](https://w3id.org/linkml/defining_slots)


## Domain and Range

class_definition &#8594;  <sub>0..\*</sub> slot_definition

## Parents


## Children


## Used by

 * class_definition
